@@ -250,6 +250,7 @@ __all__ = (
     "LaunchTemplateHttpTokensStateType",
     "LaunchTemplateInstanceMetadataEndpointStateType",
     "LaunchTemplateInstanceMetadataOptionsStateType",
+    "LaunchTemplateInstanceMetadataProtocolIpv6Type",
     "ListingStateType",
     "ListingStatusType",
     "LocalGatewayRouteStateType",
@@ -1182,6 +1183,7 @@ LaunchTemplateErrorCodeType = Literal[
 LaunchTemplateHttpTokensStateType = Literal["optional", "required"]
 LaunchTemplateInstanceMetadataEndpointStateType = Literal["disabled", "enabled"]
 LaunchTemplateInstanceMetadataOptionsStateType = Literal["applied", "pending"]
+LaunchTemplateInstanceMetadataProtocolIpv6Type = Literal["disabled", "enabled"]
 ListingStateType = Literal["available", "cancelled", "pending", "sold"]
 ListingStatusType = Literal["active", "cancelled", "closed", "pending"]
 LocalGatewayRouteStateType = Literal["active", "blackhole", "deleted", "deleting", "pending"]
